@@ -40,3 +40,15 @@ class InvalidMessageIdError(HardwareGatewayError):
 
 class RequestTimeoutError(HardwareGatewayError):
     pass
+
+
+class ConnectionError(HardwareGatewayError):
+    pass
+
+
+class ServerConnectionLostError(HardwareGatewayError):
+    pass
+
+
+class SerializationError(HardwareGatewayError):
+    pass
